@@ -9,20 +9,24 @@ the same fragment set in input. Thus, in theory fragments obtained using BRICS C
 This differs from rdkit BRICSBuild implementation that requires the presence of dummy indicator atoms added by a prior BRICS fragmentation.
 """
 
+from typing import Optional
+
 import copy
 import json
 import itertools
 import random
-import numpy as np
 import re
 import pkg_resources
 
 from functools import lru_cache
 
+import numpy as np
+
 from rdkit import Chem
 from rdkit.Chem import rdChemReactions
 
 import datamol as dm
+from ..types import Mol
 
 CCQ = "[$([#6][!#6;!#1]):1]!@[#6;!a:2]>>[*:1].[*:2]"
 CCQ_RETRO = "[$([#6;!H0][!#6;!#1]):1].[#6;!a;!H0:2]>>[*:1][*:2]"
@@ -255,7 +259,7 @@ def _run_at_all_rct(rxn, mol1, mol2):
         mol = None
         mSmi = ""
         try:
-            mSmi = Chem.MolToSmiles(m)
+            mSmi = dm.to_smiles(m)
             mol = dm.to_mol(mSmi)
         except:
             pass
@@ -263,7 +267,7 @@ def _run_at_all_rct(rxn, mol1, mol2):
             try:
                 mol.UpdatePropertyCache()
                 mol = dm.sanitize_mol(mol)
-                mSmi = Chem.MolToSmiles(m)
+                mSmi = dm.to_smiles(m)
                 mol = dm.to_mol(mSmi)
             except:
                 pass
@@ -272,7 +276,7 @@ def _run_at_all_rct(rxn, mol1, mol2):
 
 
 def break_mol(
-    mol: Chem.Mol,
+    mol: Chem.rdchem.Mol,
     minFragmentSize: int = 1,
     silent: bool = True,
     onlyUseReactions: list = [],
@@ -297,7 +301,7 @@ def break_mol(
         all_reactions_type = [all_reactions_type[ind] for ind in p]
 
     nx = dm.graph._get_networkx()
-    mSmi = Chem.MolToSmiles(mol, isomericSmiles=True)
+    mSmi = dm.to_smiles(mol, isomeric=True)
     G = nx.DiGraph()
     node_num = 0
     G.add_node(node_num, smiles=mSmi, mol=mol)
@@ -339,7 +343,7 @@ def break_mol(
                             seqOk = False
                             break
                         continue
-                    pSmi = Chem.MolToSmiles(prod, isomericSmiles=True)
+                    pSmi = dm.to_smiles(prod, isomeric=True)
                     seqOk = seqOk and (dm.to_mol(pSmi) is not None)
 
                     notDummies = sum([atm.GetSymbol() != "*" for atm in prod.GetAtoms()])
@@ -356,7 +360,7 @@ def break_mol(
                             continue
                         pSmi = prod.pSmi
                         node_num += 1
-                        usmi = Chem.MolToSmiles(dm.fix_mol(prod), isomericSmiles=True)
+                        usmi = dm.to_smiles(dm.fix_mol(prod), isomeric=True)
                         G.add_node(node_num, smiles=usmi, mol=prod)
                         G.add_edge(parent, node_num)
                         if usmi not in allNodes:
@@ -375,10 +379,12 @@ def break_mol(
 
 def build(ll_mols, max_n_mols=float("inf"), mode="brics", frag_rxn=None, ADD_RNXS=[]):
     """Build a super molecule from a list of fragments"""
+
     seen = set()
     stop = False
     CUR_RXNS = []
     CUR_RXNS_TYPE = []
+
     if mode == "brics":
         CUR_RXNS = ALL_BRICS_RETRO
         CUR_RXNS_TYPE = ALL_BRICS_TYPE
@@ -401,9 +407,11 @@ def build(ll_mols, max_n_mols=float("inf"), mode="brics", frag_rxn=None, ADD_RNX
         if (frag_rxn is not None) and (frag_rxn.strip('"') == rxn_type):
             CUR_RXNS = [CUR_RXNS[i]]
             break
+
     for fraglist in itertools.product(*ll_mols):
         if stop:
             break
+
         fraglist = list(fraglist)
         for rxn in CUR_RXNS:  # should be size==1 if frag_rxn is provided
             ps = []
@@ -421,16 +429,16 @@ def build(ll_mols, max_n_mols=float("inf"), mode="brics", frag_rxn=None, ADD_RNX
 
 
 def assemble_fragment_order(
-    fragmentlist,
-    seen=None,
+    fragmentlist: list,
+    seen: Optional[Mol] = None,
     allow_incomplete: bool = False,
     max_n_mols: float = float("inf"),
-    RXNS=ALL_BRICS_RETRO,
+    RXNS=None,
 ):
     """Assemble a list of fragment into a set of possible molecules under rules defined by the brics algorithm
 
-    ..note ::
-        We are of course assuming:
+    We are of course assuming:
+
         1. that the order in the fragmentlist matter :D !
         2. that none of the fragment has explicitly defined hydrogen atoms.
         3. only a list of unique molecule is internally maintained
@@ -439,13 +447,16 @@ def assemble_fragment_order(
         fragmentlist: list of original fragments to grow
         seen: original molecules used as base. If none, the first element of fragment list will be poped out
         allow_incomplete: Whether to accept assembled molecules with missing fragment
-
     """
+
+    if RXNS is None:
+        RXNS = ALL_BRICS_RETRO
+
     fragmentlist = list(fragmentlist)
     yield_counter = 0
     if seen is None:
         seen = fragmentlist.pop(0)
-    seen = [Chem.MolToSmiles(seen)]  # only one molecule to assemble
+    seen = [dm.to_smiles(seen)]  # only one molecule to assemble
     while yield_counter < max_n_mols and len(fragmentlist) > 0:
         # find all the way to add this fragment to seen
         frag = fragmentlist.pop(0)
@@ -477,9 +488,13 @@ def assemble_fragment_iter(
     max_n_mols=float("inf"),
     maxdepth=3,
     as_smiles=True,
-    RXNS=ALL_BRICS_RETRO,
+    RXNS=None,
 ):
-    """Perform an assembly from fragment given all potential RXNS transformation"""
+    """Perform an assembly from fragment given all potential RXNS transformation."""
+
+    if RXNS is None:
+        RXNS = ALL_BRICS_RETRO
+
     seen = set()
     if max_n_mols <= 0:
         return
@@ -488,6 +503,7 @@ def assemble_fragment_iter(
     if scrambleReagents:
         seens = list(seens)
         random.shuffle(seens, random=random.random)
+
     for seen in seens:
         nextSteps = []
         for rxn in RXNS:
@@ -507,7 +523,7 @@ def assemble_fragment_iter(
                 max_n_mols=(max_n_mols - len(seen)),
                 maxdepth=maxdepth - 1,
             ):
-                pSmi = Chem.MolToSmiles(p, True)
+                pSmi = dm.to_smiles(p, True)
                 if pSmi not in seen:
                     seen.add(pSmi)
                     yield p if not as_smiles else pSmi
