@@ -1,6 +1,8 @@
 from .jobs import JobRunner
 from .jobs import parallelized
+from .jobs import parallelized_with_batches
 
 from . import fs
+from . import perf
 
 from . import decorators
