@@ -1,4 +1,10 @@
+from . import utils
+
 from ._viz import to_image
+
+from ._substructure import match_substructure
+
 from ._conformers import conformers
+
 from ._circle_grid import circle_grid
 from ._circle_grid import MolsCircleGrid
